summaryrefslogtreecommitdiffstats
path: root/src/gui/kdeext/QCanvasGroupableItem.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/kdeext/QCanvasGroupableItem.h')
-rw-r--r--src/gui/kdeext/QCanvasGroupableItem.h62
1 files changed, 31 insertions, 31 deletions
diff --git a/src/gui/kdeext/QCanvasGroupableItem.h b/src/gui/kdeext/QCanvasGroupableItem.h
index 1e54604..b7d4fbb 100644
--- a/src/gui/kdeext/QCanvasGroupableItem.h
+++ b/src/gui/kdeext/QCanvasGroupableItem.h
@@ -19,47 +19,47 @@
COPYING included with this distribution for more information.
*/
-#ifndef QCANVASGROUPABLEITEM_H
-#define QCANVASGROUPABLEITEM_H
+#ifndef TQCANVASGROUPABLEITEM_H
+#define TQCANVASGROUPABLEITEM_H
#include <tqcanvas.h>
-class QCanvasItemGroup;
+class TQCanvasItemGroup;
/**
- * This class is meant to be inherited by TQCanvasItem children to make
+ * This class is meant to be inherited by TQCanvasItem tqchildren to make
* them groupable.
*
* On destruction, the item will remove itself from the group it's
* attached to.
*
* @see QCanvasSpriteGroupable
- * @see QCanvasLineGroupable
+ * @see TQCanvasLineGroupable
*/
class QCanvasGroupableItem
{
- friend class QCanvasItemGroup;
+ friend class TQCanvasItemGroup;
public:
/**
* Create a groupable item, e.g. put the item in the specified
* QCanvasItemGroup. If withRelativeCoords is true, the item's
* position will be translated so that it's coordinates are
* relative to those of the item group.
*
- * @see QCanvasItemGroup#addItemWithRelativeCoords()
+ * @see TQCanvasItemGroup#addItemWithRelativeCoords()
*/
- QCanvasGroupableItem(TQCanvasItem*, QCanvasItemGroup*,
+ QCanvasGroupableItem(TQCanvasItem*, TQCanvasItemGroup*,
bool withRelativeCoords = false);
virtual ~QCanvasGroupableItem();
- /// Returns the QCanvasItemGroup this groupable item belongs to
- QCanvasItemGroup* group() { return m_group; }
+ /// Returns the TQCanvasItemGroup this groupable item belongs to
+ TQCanvasItemGroup* group() { return m_group; }
- /// Returns the QCanvasItemGroup this groupable item belongs to
- const QCanvasItemGroup* group() const { return m_group; }
+ /// Returns the TQCanvasItemGroup this groupable item belongs to
+ const TQCanvasItemGroup* group() const { return m_group; }
/// Returns the TQCanvasItem which this groupable item wraps
TQCanvasItem *item() { return m_item; }
@@ -72,7 +72,7 @@ public:
protected:
/**
* Detach item from the item group - called by QCanvasItemGroup only
*
* Set m_group to 0, so that on destruction the item won't try to
* remove itself from the group
@@ -82,7 +82,7 @@ protected:
private:
//--------------- Data members ---------------------------------
- QCanvasItemGroup* m_group;
+ TQCanvasItemGroup* m_group;
TQCanvasItem* m_item;
};
@@ -98,13 +98,13 @@ private:
* Proper behavior requires collaboration from the TQCanvasView,
* though. When about to move an item, the TQCanvasView object should
* first check if it's not a groupable item, and if so fetch its
* QCanvasItemGroup and move it instead.
*/
-class QCanvasItemGroup : public QCanvasItem
+class TQCanvasItemGroup : public TQCanvasItem
{
public:
- QCanvasItemGroup(TQCanvas *);
- virtual ~QCanvasItemGroup();
+ TQCanvasItemGroup(TQCanvas *);
+ virtual ~TQCanvasItemGroup();
virtual void moveBy(double dx, double dy);
virtual void advance(int stage);
@@ -131,7 +131,7 @@ public:
* Add a new item to this group.
*
* The item's coordinates are considered relative to the group.
* For example, suppose you have a QCanvasItemGroup whose coords
* are 10,10. If you call addItemWithRelativeCoords() with an item
* whose coords are 5,5, the item is moved so that its coords
* will be 5,5 relative to the group (e.g. 15,15).
@@ -162,40 +162,40 @@ protected:
/**
* A TQCanvasLine which can be put in a QCanvasGroup
*/
-class QCanvasLineGroupable : public TQCanvasLine, public QCanvasGroupableItem
+class TQCanvasLineGroupable : public TQCanvasLine, public QCanvasGroupableItem
{
public:
- QCanvasLineGroupable(TQCanvas *c, QCanvasItemGroup *g);
+ TQCanvasLineGroupable(TQCanvas *c, TQCanvasItemGroup *g);
};
/**
* A TQCanvasRectangle which can be put in a QCanvasGroup
*/
-class QCanvasRectangleGroupable : public TQCanvasRectangle, public QCanvasGroupableItem
+class TQCanvasRectangleGroupable : public TQCanvasRectangle, public QCanvasGroupableItem
{
public:
- QCanvasRectangleGroupable(TQCanvas *c, QCanvasItemGroup *g);
+ TQCanvasRectangleGroupable(TQCanvas *c, TQCanvasItemGroup *g);
};
/**
* A TQCanvasText which can be put in a QCanvasGroup
*/
-class QCanvasTextGroupable : public TQCanvasText, public QCanvasGroupableItem
+class TQCanvasTextGroupable : public TQCanvasText, public QCanvasGroupableItem
{
public:
- QCanvasTextGroupable(TQCanvas *c, QCanvasItemGroup *g);
- QCanvasTextGroupable(const TQString&, TQCanvas *c, QCanvasItemGroup *g);
+ TQCanvasTextGroupable(TQCanvas *c, TQCanvasItemGroup *g);
+ TQCanvasTextGroupable(const TQString&, TQCanvas *c, TQCanvasItemGroup *g);
};
/**
- * A TQCanvasSprite that can be put in a QCanvasGroup
+ * A QCanvasSprite that can be put in a QCanvasGroup
*/
-class QCanvasSpriteGroupable : public TQCanvasSprite, public QCanvasGroupableItem
+class TQCanvasSpriteGroupable : public TQCanvasSprite, public QCanvasGroupableItem
{
public:
- QCanvasSpriteGroupable(TQCanvasPixmapArray*,
+ TQCanvasSpriteGroupable(TQCanvasPixmapArray*,
TQCanvas*,
- QCanvasItemGroup*);
+ TQCanvasItemGroup*);
};
#endif
@@ -19,47 +19,47 @@
/**
* Create a groupable item, e.g. put the item in the specified
- * QCanvasItemGroup. If withRelativeCoords is true, the item's
+ * TQCanvasItemGroup. If withRelativeCoords is true, the item's
* position will be translated so that it's coordinates are
* relative to those of the item group.
@@ -72,7 +72,7 @@ public:
protected:
/**
- * Detach item from the item group - called by QCanvasItemGroup only
+ * Detach item from the item group - called by TQCanvasItemGroup only
*
* Set m_group to 0, so that on destruction the item won't try to
@@ -98,13 +98,13 @@ private:
* though. When about to move an item, the TQCanvasView object should
* first check if it's not a groupable item, and if so fetch its
- * QCanvasItemGroup and move it instead.
+ * TQCanvasItemGroup and move it instead.
*/
@@ -131,7 +131,7 @@ public:
*
* The item's coordinates are considered relative to the group.
- * For example, suppose you have a QCanvasItemGroup whose coords
+ * For example, suppose you have a TQCanvasItemGroup whose coords
* are 10,10. If you call addItemWithRelativeCoords() with an item
* whose coords are 5,5, the item is moved so that its coords